archive

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 19, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Tar

func Tar(w io.Writer, src string) error

Tar creates a tar archive from the given source file or directory and writes it to w. It preserves file structure and metadata.

func Untar

func Untar(r io.Reader, dest string) error

Untar extracts a tar archive from r into the destination directory dest. It performs security checks to prevent path traversal and preserves file structure and metadata.

Types

This section is empty.

Jump to